@@ -36,4 +36,11 @@ except ImportError as e:
     logger.warning(warning_msg.format("Proxy Service"))
     logger.warning(f"{e}")
 
+try:
+    from sermos.cli.version import get_version
+    collection.append(get_version)
+except ImportError as e:
+    logger.warning(warning_msg.format("Version"))
+    logger.warning(f"{e}")
+
 sermos = click.CommandCollection(sources=collection)
