@@ -7,7 +7,8 @@ API_PATH_V1 = '/api/v1'
 
 DEFAULT_RESULT_TTL = 86400  # seconds (1 day)
 DEFAULT_TASK_TTL = 60  # seconds (1 minute)
-DEFAULT_MAX_RETRY = 3
+DEFAULT_RETRY_TASK_MAX_TTL = 300
+DEFAULT_MAX_RETRY = 10
 DEFAULT_REGULATOR_TASK = 'sermos.celery.task_chain_regulator'
 DEFAULT_SUCCESS_TASK = 'sermos.celery.pipeline_success'
 DEFAULT_RETRY_TASK = 'sermos.celery.pipeline_retry'
@@ -44,10 +45,14 @@ LOCAL_DEPLOYMENT_VALUE = os.environ.get('LOCAL_DEPLOYMENT_VALUE', 'local')
 DEFAULT_BASE_URL = os.environ.get('SERMOS_BASE_URL', 'https://console.sermos.ai')
 if DEFAULT_BASE_URL != 'local':
     DEFAULT_BASE_URL += '/api/v1/'
-DEFAULT_DEPLOY_URL = urljoin(DEFAULT_BASE_URL, 'deploy')
+DEPLOYMENTS_URL = "{}deployments/{}"
+DEPLOYMENTS_DEPLOY_URL = "{}deployments/{}/deploy"
+DEPLOYMENTS_SERVICES_URL = "{}deployments/{}/services"
+DEPLOYMENTS_SERVICE_URL = "{}deployments/{}/services/{}"
+PROXY_SERVICE_URL = "{}deployments/{}/proxy-token/{}"
 DEFAULT_AUTH_URL = urljoin(DEFAULT_BASE_URL, 'auth')
 USING_SERMOS_CLOUD = DEFAULT_BASE_URL != LOCAL_DEPLOYMENT_VALUE
-
+DEFAULT_CONFIG_RETRIEVAL_PAGE_SIZE = 25
 # Default 'responses' dictionary when decorating endpoints with @api.doc()
 # Extend as necessary.
 API_DOC_RESPONSES = {
