@@ -1,7 +1,9 @@
 """ Pipeline APIs
 """
-import os
 import logging
+
+from celery.canvas import _chain
+from celery_dyrygent.workflows import Workflow
 from flask import jsonify, request
 from flask.views import MethodView
 from rho_web.smorest import Blueprint
@@ -40,9 +42,9 @@ class InvokePipelineResponseSchema(Schema):
 
 class GetPipelineResultResponseSchema(Schema):
     execution_id = fields.String()
-    result = fields.Dict()
+    result = fields.Raw()
     result_ttl = fields.Integer()
-    results = fields.Dict()
+    results = fields.Raw()
     status = fields.String()
     status_message = fields.String()
 
@@ -161,7 +163,11 @@ class PipelineInvoke(MethodView):
 
             if gen.chain is None:
                 abort(400, message=gen.loading_message)
-            gen.chain.apply_async()  # Invoke the pipeline
+
+            chain: _chain = gen.chain
+            wf: Workflow = Workflow()
+            wf.add_celery_canvas(chain)
+            wf.apply_async()
             retval['status'] = 'success'
             retval['execution_id'] = gen.execution_id
             # Initialize the cached result
@@ -219,7 +225,6 @@ class PipelineResults(MethodView):
             pr = PipelineResult(execution_id)
             pr.load()
             retval = pr.to_dict()
-
             if pr.status == 'unavailable':
                 retval['status_message'] = 'Results expired. Re-run pipeline.'
                 return retval, 204
@@ -233,7 +238,8 @@ class PipelineResults(MethodView):
                 return retval, 200
 
         except Exception as e:
-            msg = "Failed to invoke pipeline ... {}".format(execution_id)
+            msg = "Failed to retrieve results for execution id: {}".format(
+                execution_id)
             logger.error(msg)
             logger.exception(f"{e}")
             abort(500, message=msg)
