@@ -102,7 +102,7 @@ import yaml
 from yaml.loader import SafeLoader
 from marshmallow import Schema, fields, pre_load, EXCLUDE, INCLUDE,\
     validates_schema
-from marshmallow.validate import OneOf
+from marshmallow.validate import OneOf, Range
 from marshmallow.exceptions import ValidationError
 from sermos.utils.module_utils import SermosModuleLoader, normalized_pkg_name
 from sermos.constants import SERMOS_YAML_PATH, SERMOS_CLIENT_PKG_NAME
@@ -195,6 +195,64 @@ class ServiceRequestsSchema(Schema):
         example="2 (means 2 GB)")
 
 
+class SermosServiceHealthCheckSchema(Schema):
+    healthCheckType = fields.String(
+        required=False,
+        description="Type of health check to use.",
+        example="TCP or HTTP",
+        validate=OneOf(['TCP', 'HTTP']))
+    healthCheckPort = fields.Integer(
+        required=False,
+        description="Port (and targetPort) for health check.",
+        validate=Range(min_inclusive=1, max_inclusive=65535),
+        example=8080)
+    healthCheckPath = fields.String(
+        required=False,
+        description="Path to access on the HTTP Server.",
+        example="/healthz",
+        default='/'
+    )
+    healthCheckInitialDelaySeconds = fields.Integer(
+        required=False,
+        description="Number of seconds after the container has started before\
+         health check probes are initiated.",
+        example=0,
+        default=0,
+        validate=Range(min_inclusive=0)
+    )
+    healthCheckPeriodSeconds = fields.Integer(
+        required=False,
+        description="How often (in seconds) to perform the health check probe.",
+        example=10,
+        default=10,
+        validate=Range(min_inclusive=1)
+    )
+    healthCheckTimeoutSeconds = fields.Integer(
+        required=False,
+        description="Number of seconds after which the health check "
+                    "probe times out",
+        example=1,
+        default=1,
+        validate=Range(min_inclusive=1)
+    )
+    healthCheckSuccessThreshold = fields.Integer(
+        required=False,
+        description="Minimum consecutive successes for the health check "
+                    "probe to be considered successful after having failed.",
+        example=1,
+        default=1,
+        validate=Range(min_inclusive=1)
+    )
+    healthCheckFailureThreshold = fields.Integer(
+        required=False,
+        description="Maximum consecutive failures for the health check "
+                    "probe.  Service will restart upon threshold met.",
+        example=3,
+        default=3,
+        validate=Range(min_inclusive=1)
+    )
+
+
 class NameSchema(Schema):
     """ Validated name string field.
     """
@@ -353,7 +411,8 @@ class SermosServiceConfigSchema(ExcludeUnknownSchema, ServiceRequestsSchema,
                                 EnvironmentVariablesSchema,
                                 SermosExternalConfigSchema,
                                 SermosInternalSchema,
-                                SermosCeleryWorkerConfigSchema, NameSchema):
+                                SermosCeleryWorkerConfigSchema, NameSchema,
+                                SermosServiceHealthCheckSchema):
     """ Base service config object definition for workers and internal/external
         services.
     """
