@@ -1,7 +1,6 @@
 """ Utilities for running and managing tasks inside pipelines.
 """
 import os
-import json
 import logging
 import uuid
 from typing import List, Any, Union
@@ -11,7 +10,8 @@ from celery import chain, signature, chord
 from sermos.constants import DEFAULT_TASK_TTL, \
     DEFAULT_REGULATOR_TASK, CHAIN_SUCCESS_MSG, CHAIN_FAILURE_MSG, \
     PIPELINE_RUN_WRAPPER_CACHE_KEY, DEFAULT_SUCCESS_TASK, DEFAULT_RESULT_TTL, \
-    PIPELINE_RESULT_CACHE_KEY, DEFAULT_RETRY_TASK, DEFAULT_MAX_RETRY
+    PIPELINE_RESULT_CACHE_KEY, DEFAULT_RETRY_TASK, DEFAULT_MAX_RETRY, \
+    DEFAULT_RETRY_TASK_MAX_TTL
 from sermos_tools import SermosTool
 from sermos.utils.graph_utils import get_execution_graph, get_chainable_tasks
 from sermos.utils.config_utils import retrieve_latest_pipeline_config, \
@@ -190,11 +190,10 @@ class PipelineRunWrapper(SermosTool):
         return ('pipeline_config', 'max_ttl', 'max_retry', 'retry_count',
                 'chain_payload', 'pipeline_id')
 
-    def _load_from_cache(self):
+    def _load_from_cache(self, is_retry=False):
         """ Attempt to load this PipelineRunWrapper from cache.
         """
         logger.debug(f"Attempting to load {self.cache_key} from cache")
-        msg = "Loaded from cache."
         try:
             cached_wrapper = load_json_config_from_redis(self.cache_key)
             if cached_wrapper is not None:
@@ -207,9 +206,10 @@ class PipelineRunWrapper(SermosTool):
             else:
                 raise ValueError(f"Unable to find {self.cache_key} ...")
         except Exception as e:
-            self.good_to_go = False
-            self.loading_message = e
-            logger.exception(e)
+            if not is_retry:
+                self.good_to_go = False
+                self.loading_message = e
+                logger.exception(e)
 
         if self.pipeline_config is None:
             raise ValueError("pipeline_config not set, invalid ...")
@@ -226,7 +226,9 @@ class PipelineRunWrapper(SermosTool):
         cached_json = {}
         for key in self._cachable_keys:
             cached_json[key] = getattr(self, key)
-        set_json_config_to_redis(self.cache_key, cached_json, self.max_ttl)
+        ttl = (self.max_ttl *
+               len(self.pipeline_config['taskDefinitions'])) + 10
+        set_json_config_to_redis(self.cache_key, cached_json, ttl)
 
     @classmethod
     def from_event(cls, event):
@@ -262,8 +264,8 @@ class PipelineRunWrapper(SermosTool):
             # an event, the run wrapper can be loaded using only the pipeline
             # id and execution id, the pipeline config is then initialized from
             # the wrapper
-            if self.pipeline_config is None:
-                self._load_from_cache()
+            if self.pipeline_config is None or is_retry:
+                self._load_from_cache(is_retry=is_retry)
             else:
                 # If the pipeline_config is set before .load(), that means
                 # this invocation is coming from an initial load, not cache.
@@ -606,6 +608,7 @@ class PipelineGenerator(object):
                                   access_key=self.access_key,
                                   pipeline_id=self.pipeline_id,
                                   execution_id=self.execution_id,
+                                  max_ttl=DEFAULT_RETRY_TASK_MAX_TTL,
                                   custom_event_data={
                                       'queue': self.queue,
                                       'default_task_ttl':
